# HG changeset patch
# User Pavel Shramov <psha@void.psha.org.ru>
# Date 1337370597 -14400
# Node ID 8bccd71ebb62a86ad9fbc1d3557ec90060a28d0e
# Parent  17c410cae5a7ea06889a2bb3ce43197790b1dc56
Use Spatialite friendly query syntax

There is no && operator so use ST_Intersects in spatialite mode

diff -r 17c410cae5a7 -r 8bccd71ebb62 src/komap.py
--- a/src/komap.py	Tue May 08 13:22:19 2012 +0300
+++ b/src/komap.py	Fri May 18 23:49:57 2012 +0400
@@ -135,7 +135,18 @@
     return "(tags->'"+name+"') as \"" +name+'"'
 
 
+def sql_intersects_spatialite(v1, v2):
+  if not v1.startswith("ST_Expand"): v1 = "ST_Expand((%s), 0)" % v1
+  if not v2.startswith("ST_Expand"): v2 = "ST_Expand((%s), 0)" % v2
+  return "ST_Intersects(%s, %s)" % (v1, v2)
 
+def sql_intersects_postgis(v1, v2):
+  return "%s &amp;&amp; %s" % (v1, v2)
+
+if config.has_option('mapnik', 'db_type') and config.get('mapnik', 'db_type') == 'spatialite':
+  sql_intersects = sql_intersects_spatialite
+else:
+  sql_intersects = sql_intersects_postgis
 
 
 
@@ -850,11 +861,11 @@
                     else:
                       order += ", "
                     #itags = "\""+ itags+"\""
-                    sqlz = """select * from (select %s, ST_Simplify(ST_LineMerge(ST_Union(way)),%s) as way from (SELECT * from %sline where way &amp;&amp; ST_Expand(!bbox!,%s) and (%s) and (%s)) as tex
+                    sqlz = """select * from (select %s, ST_Simplify(ST_LineMerge(ST_Union(way)),%s) as way from (SELECT * from %sline where %s and (%s) and (%s)) as tex
                     group by %s) p
                     where ST_Length(p.way) > %s
                     %s ST_Length(p.way) desc
-                    """%(itags,pixel_size_at_zoom(zoom,3),libkomapnik.table_prefix,max(pixel_size_at_zoom(zoom,20),3000),ttext,sqlz,goitags,pixel_size_at_zoom(zoom,4),order)
+                    """%(itags,pixel_size_at_zoom(zoom,3),libkomapnik.table_prefix,sql_intersects("way", "ST_Expand(!bbox!,%s)" % max(pixel_size_at_zoom(zoom,20),3000)),ttext,sqlz,goitags,pixel_size_at_zoom(zoom,4),order)
                     mfile.write(xml_layer("postgis-process", layer_type, itags, sqlz, zoom=zoom ))
 
 
@@ -938,4 +949,4 @@
                 else:
                   xml_nolayer()
 
-  mfile.write(xml_end())
\ No newline at end of file
+  mfile.write(xml_end())
